@@ -1,8 +1,8 @@
 from numcodecs.registry import get_codec, register_codec
 
-from .codecs.mp4 import MP4
+from .codecs.h264 import H264
 
-register_codec(MP4)
+register_codec(H264)
 
 
 from .videodataset import VideoDataset
@@ -13,4 +13,4 @@ from .backend import open_video
 
 __author__ = """Oceanum Developers"""
 __email__ = "developers@oceanum.science"
-__version__ = "0.2.2"
+__version__ = "0.2.6"
